@@ -1,5 +1,5 @@
 package HTML::Template::Compiled::Compiler;
-# $Id: Compiler.pm 1128 2011-10-31 19:59:56Z tinita $
+# $Id: Compiler.pm 1145 2012-04-21 19:51:39Z tinita $
 use strict;
 use warnings;
 use Data::Dumper;
@@ -117,6 +117,11 @@ sub _escape_expression {
                 _expr_function( 'HTML::Template::Compiled::Utils::escape_js',
                 $exp, );
         }
+        elsif ( $_ eq 'IJSON' ) {
+            $exp =
+                _expr_function( 'HTML::Template::Compiled::Utils::escape_ijson',
+                $exp, );
+        }
         elsif ( $_ eq 'DUMP' ) {
             $exp = _expr_method( 'dump', _expr_literal('$t'), $exp, );
         }
@@ -246,6 +251,7 @@ sub parse_var {
     my $use_objects = $t->get_objects;
     my $strict = $use_objects eq 'strict' ? 1 : 0;
     my $method_args = '';
+    my $hash_key = $args{hash_key};
     my $varstr = '';
     @split = map {
         s#\\#\\\\#g;
@@ -358,6 +364,9 @@ sub parse_var {
 
         $count++;
     }
+    if (defined $hash_key) {
+        $varstr = "($varstr\->{$hash_key})";
+    }
     #my $final = $context->get_name eq 'VAR' ? 1 : 0;
     if (0 or @split > 1) {
         $varstr = "do { my $varname = $initial_var; $varstr $varname }";
